pub struct BufferSource { /* private fields */ }Expand description
Source implementation for reading JSON data from a memory buffer A memory buffer implementation for reading JSON data from bytes. Provides functionality to traverse and read byte content from memory.
Implementations